![GitHub last commit](https://img.shields.io/github/last-commit/taruma/umakit.svg) ![PyPI](https://img.shields.io/pypi/v/umakit.svg)
![GitHub](https://img.shields.io/github/license/taruma/umakit.svg)

# umakit
Paket python pribadi

`umalog.logtool` untuk alat pencatat (logging)
